@@ -96,7 +96,7 @@ class MysqlPool(object):
     def __init__(self, db, host, port, user, pwd, **kwargs):
 
         pool_config = {
-            'creator': 'pymysql',  # 使用链接数据库的模块
+            'creator': pymysql,  # 使用链接数据库的模块
             'maxconnections': 6,  # 连接池允许的最大连接数，0和None表示不限制连接数
             'mincached': 2,  # 初始化时，链接池中至少创建的空闲的链接，0表示不创建
             'maxcached': 5,  # 链接池中最多闲置的链接，0和None不限制
@@ -129,6 +129,12 @@ class MysqlPool(object):
             cls._instance = object.__new__(cls)
         return cls._instance
 
+    def __del__(self):
+        try:
+            self.pool.close()
+        except Exception:
+            pass
+
     def execute_sql(self, sql, **args):
         try:
             sql = sql.lower()
@@ -215,5 +221,5 @@ class MysqlPool(object):
 
 class TaskMysql(MysqlPool, Mysql):
     def __init__(self, db, host, port, user, pwd, **kwargs):
-        super().__init__(db=db, host=host, port=port,
-                         user=user, pwd=pwd, **kwargs)
+        super().__init__(db=str(db), host=host, port=port,
+                         user=str(user), pwd=str(pwd), **kwargs)
