@@ -68,8 +68,15 @@ def is_domain(domain, use_tld=False):
             return False
     else:
         try:
-            get_tld(domain)
-        except:
+            res = get_tld(domain)
+        except Exception as e:
+            if "didn't match any existing TLD name" in str(e):
+                try:
+                    if domain.startswith('http') and re.search(
+                            r'((2(5[0-5]|[0-4]\d))|[0-1]?\d{1,2})(\.((2(5[0-5]|[0-4]\d))|[0-1]?\d{1,2})){3}', domain):
+                        return True
+                except:
+                    pass
             return False
     return res
 
